package com.steerinfo.dil.controller;

import com.alibaba.fastjson.JSON;
import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.model.TmsshipLoadShipResult;
import com.steerinfo.dil.model.TmsshipUnloadShipResult;
import com.steerinfo.dil.service.ITmsshipUnloadShipResultService;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import com.steerinfo.framework.service.pagehelper.PageList;
import com.steerinfo.framework.utils.collection.ListUtils;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.*;
import java.math.BigDecimal;

/**
 * TmsshipUnloadShipResult RESTful接口：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-08-19 08:57
 * 类描述
 * 修订历史：
 * 日期：2021-08-19
 * 作者：generator
 * 参考：
 * 描述：TmsshipUnloadShipResult RESTful接口
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@RestController
@RequestMapping("/${api.version}/tmsshipunloadshipresults")
public class TmsshipUnloadShipResultController extends BaseRESTfulController {

    @Autowired
    ITmsshipUnloadShipResultService tmsshipUnloadShipResultService;
    @Autowired
    ColumnDataUtil columnDataUtil;
    @Autowired
    ESFeign esFeign;
    /**
     * 新增卸船作业
     * @param map
     * @return
     */
    @ApiOperation(value="新增卸船作业", notes="根据TmsshipUnloadShipResult对象创建")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "map",value = "卸船作业字段",required = true,paramType = "java.util.Map")
    })
    @PostMapping("/addUnLoadShip")
    public RESTfulResult addUnLoadShip(@RequestBody Map<String,Object> map) {
        int code = tmsshipUnloadShipResultService.insertUnloadShip(map);
        return success(code);
    }


    /**
     * 修改卸船作业信息
     * @param tmsshipUnloadShipResult
     * @return
     */
    @ApiOperation(value="修改卸船作业信息", notes="根据TmsshipUnloadShipResult对象修改")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "tmsshipUnloadShipResult",value = "卸船作业字段",required = true,paramType = "TmsshipUnloadShipResult")
    })
    @PostMapping("/updateUnLoadShip")
    public RESTfulResult updateUnLoadShip(@RequestBody TmsshipUnloadShipResult tmsshipUnloadShipResult) {
        int code = tmsshipUnloadShipResultService.updateUnloadShip(tmsshipUnloadShipResult);
        return success(code);
    }

    /**
     * 删除卸船作业信息
     * @param resultId
     * @return
     */
    @ApiOperation(value="删除卸船作业信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "resultId",value = "卸船作业字段",required = true,paramType = "BigDecimal")
    })
    @PostMapping("/deleteUnLoadShip/{resultId}")
    public RESTfulResult deleteUnLoadShip(@PathVariable("resultId") BigDecimal resultId) {
        int code = tmsshipUnloadShipResultService.deleteUnloadShip(resultId);
        return success(code);
    }

    /**
     * 查询卸船作业信息
     * @param reusltId
     * @return
     */
    @ApiOperation(value="查询卸船作业信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "reusltId",value = "卸船作业字段",required = true,paramType = "java.util.Map")
    })
    @PostMapping("/selectUnLoadShip/{reusltId}")
    public RESTfulResult selectUnLoadShip(@PathVariable("reusltId") BigDecimal reusltId) {
        TmsshipUnloadShipResult tmsshipUnloadShipResult = tmsshipUnloadShipResultService.selectUnloadShip(reusltId);
        return success(tmsshipUnloadShipResult);
    }

    /**
     * 查询卸船作业信息
     * @param resultId
     * @return
     */
    @ApiOperation(value="查询卸船作业信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "resultId",value = "卸船作业字段",required = true,paramType = "BigDecimal")
    })
    @PostMapping("/getUnloadShip/{resultId}")
    public RESTfulResult getUnloadShip(@PathVariable("resultId") BigDecimal resultId) {
        List<Map<String,Object>> tmsshipUnloadShipResult = tmsshipUnloadShipResultService.getUnloadShip(resultId);
        return success(tmsshipUnloadShipResult);
    }

    /**
     * 展示卸船作业信息列表
     * @param mapVal
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiOperation(value="展示卸船作业信息列表", notes="分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "68", required = false, dataType = "BigDecimal"),
    })
    @PostMapping(value = "/getUnLoadShipList")
    public RESTfulResult getUnLoadShipList(@RequestBody(required = false) Map<String,Object> mapVal,
                                           Integer pageNum,
                                           Integer pageSize,
                                           Integer apiId,
                                           String con){
        if(con!=null&&!con.equals("null")){
            mapVal.put("con","%"+con+"%");
        }
        List<Map<String, Object>> detailListTotal = tmsshipUnloadShipResultService.selectUnloadShipList(mapVal);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = tmsshipUnloadShipResultService.selectUnloadShipList(mapVal);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, detailListTotal, columnList);
        return success(data);

    }

}
